================
Differential Operators
================

.. autoclass:: findiff.Diff
    :members:
    :undoc-members:
    :inherited-members:

.. autoclass:: findiff.Gradient
    :members:
    :undoc-members:
    :inherited-members:


.. autoclass:: findiff.Divergence
    :members:
    :undoc-members:
    :inherited-members:

.. autoclass:: findiff.Curl
    :members:
    :undoc-members:
    :inherited-members:


.. autoclass:: findiff.Laplacian
    :members:
    :undoc-members:
    :inherited-members:


